@@ -60,6 +60,9 @@ The output of `omicron-process` is a Directed Acyclic Graph (DAG) that is
 """
 import time
 prog_start = time.time()
+
+from gwpy.segments import SegmentList, Segment
+
 import argparse
 import configparser
 import os
@@ -111,6 +114,53 @@ def gps2str(gps):
     return ret
 
 
+def clean_dirs(dir_list):
+    """Remove any empty directories we created
+    NB: each of those directories may contain subdirectories which we will also delete if empty
+    """
+    for adir in dir_list:
+        pdir = Path(adir)
+        flist = list(pdir.glob('*'))
+        if len(flist) == 0:
+            pdir.rmdir()
+        else:
+            can_delete = True
+            for file in flist:
+                if file.is_dir():
+                    can_delete &= remove_empty_dir(file)
+                else:
+                    # we found a file. Do not delete this direcory
+                    can_delete = False
+
+            if can_delete:
+                pdir.rmdir()
+
+
+def remove_empty_dir(dir_path):
+    """
+    Remove a directory if empty or if all it contains is empty directories.
+    This is a recursive function, it calls itself if it finds a directory.
+    :@param Path dir_path: directory to check
+    :@return boolean: True if directory was deleted
+    """
+    ret = True
+    if not dir_path.is_dir():
+        ret = False
+    else:
+        flist = list(dir_path.glob('*'))
+        if len(flist) == 0:
+            dir_path.rmdir()
+        else:
+            for file in flist:
+                if file.is_dir():
+                    ret = remove_empty_dir(file)
+                    if not ret:
+                        break
+            if ret:
+                dir_path.rmdir()
+    return ret
+
+
 def clean_tempfiles(tempfiles):
     for f in map(Path, tempfiles):
         if f.is_dir():
@@ -206,6 +256,7 @@ https://pyomicron.readthedocs.io/en/latest/"""
         help='additional file tag to be appended to final '
         'file descriptions',
     )
+    outg.add_argument('-l', '--log-file', type=Path, help="save a copy of all logger messages to this file")
 
     # data processing/chunking options
     procg = parser.add_argument_group('Processing options')
@@ -413,6 +464,11 @@ def main(args=None):
     # apply verbosity to logger
     args.verbose = max(5 - args.verbose, 0)
     logger.setLevel(args.verbose * 10)
+    if args.log_file:
+        logger.add_file_handler(args.log_file)
+    logger.debug("Command line args:")
+    for arg in vars(args):
+        logger.debug(f'{arg} = {str(getattr(args, arg))}')
 
     # validate command line arguments
     if args.ifo is None:
@@ -622,7 +678,8 @@ def main(args=None):
     pardir = rundir / "parameters"
     trigdir = rundir / "triggers"
     mergedir = rundir / "merge"
-    for d in [cachedir, condir, logdir, pardir, trigdir, mergedir]:
+    run_dir_list = [cachedir, condir, logdir, pardir, trigdir, mergedir]
+    for d in run_dir_list:
         d.mkdir(exist_ok=True)
 
     oconfig.set('OUTPUT', 'DIRECTORY', str(trigdir))
@@ -710,6 +767,7 @@ def main(args=None):
     if dataduration < minduration and online:
         logger.info("Segment is too short (%d < %d), please try again later"
                     % (duration, minduration))
+        clean_dirs(run_dir_list)
         clean_exit(0, tempfiles)
     elif dataduration < minduration:
         raise ValueError(
@@ -725,6 +783,7 @@ def main(args=None):
         logger.info(f'Finding segments for relevant state...  from:{datastart} length: {dataduration}s')
         seg_qry_strt = time.time()
         if statebits == "guardian":  # use guardian
+            logger.debug(f'Using guardian for {statechannel}: {datastart}-{dataend}')
             segs = segments.get_guardian_segments(
                 statechannel,
                 stateft,
@@ -733,6 +792,7 @@ def main(args=None):
                 pad=statepad,
             )
         else:
+            logger.debug(f'Using segdb for {statechannel}: {datastart}-{dataend}')
             segs = segments.get_state_segments(
                 statechannel,
                 stateft,
@@ -751,6 +811,13 @@ def main(args=None):
                                              pad=statepad)
         logger.info(f'Segment query took {time.time() - seg_qry_strt:.2f}s')
 
+    # Get segments from frame cache
+    elif args.cache_file:
+        cache = read_cache(str(args.cache_file))
+        cache_segs = segments.cache_segments(cache)
+        srch_span = SegmentList([Segment(datastart, dataend)])
+        segs = cache_segs & srch_span
+
     # get segments from frame availability
     else:
         segs = segments.get_frame_segments(ifo, frametype, datastart, dataend)
@@ -855,6 +922,18 @@ def main(args=None):
         logger.warning("Not all state times are available in frames")
     segs = (cachesegs & segs).coalesce()
 
+    # Deal with segments that cross a metric day (100,000 boundary)
+    seg_tmp = SegmentList()
+    for seg in segs:
+        sday = int(seg[0] / 1e5)
+        eday = int(seg[1] / 1e5)
+        if sday == eday:
+            seg_tmp.append(seg)
+        else:
+            seg1 = Segment(seg[0], eday)
+            seg2 = Segment(eday, seg[1])
+            seg_tmp.append(seg1)
+            seg_tmp.append(seg2)
     # apply minimum duration requirement
     segs = type(segs)(s for s in segs if abs(s) >= segdur)
 
@@ -868,10 +947,13 @@ def main(args=None):
         )
         segments.write_segments(cachesegs, segfile)
         logger.info("Segments written to\n%s" % segfile)
+        clean_dirs(run_dir_list)
         clean_exit(0, tempfiles)
+
     # otherwise not all data are available, so
     elif len(segs) == 0 and online:
         logger.info("No analysable segments found, please try again later")
+        clean_dirs(run_dir_list)
         clean_exit(0, tempfiles)
     elif len(segs) == 0:
         raise RuntimeError("No analysable segments found")
@@ -939,7 +1021,7 @@ def main(args=None):
 
     ojob.add_condor_cmd('+OmicronProcess', f'"{group}"')
 
-    # create post-processing job
+    # create post-processing jobs
     ppjob = condor.OmicronProcessJob(args.universe, find_executable('bash'),
                                      subdir=condir, logdir=logdir,
                                      tag='post-processing', **condorcmds)
